/*
    * @name: vuescroll 3.3.16
    * @author: (c) 2018-2018 wangyi7099
    * @description: A virtual scrollbar based on vue.js 2.x inspired by slimscroll
    * @license: MIT
    * @GitHub: https://github.com/wangyi7099/vuescroll
    */
   
(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('vue')) :
	typeof define === 'function' && define.amd ? define(['vue'], factory) :
	(global.vuescroll = factory(global.Vue));
}(this, (function (Vue) { 'use strict';

Vue = Vue && Vue.hasOwnProperty('default') ? Vue['default'] : Vue;

// vertical rail
var vRail = {
    name: 'vRail',
    render: function render(_c) {
        var vm = this;
        var style = {
            position: 'absolute',
            top: 0,
            height: '100%',
            width: vm.ops.width,
            background: vm.ops.background,
            opacity: vm.ops.opacity,
            borderRadius: '4px'
        };
        // determine the position
        if (vm.ops.pos == 'right') {
            style['right'] = 0;
        } else {
            style['left'] = 0;
        }

        return _c('div', {
            style: style,
            on: {
                "click": function click(e) {
                    vm.$emit('scrollContentByBar', e, 'vScrollbar');
                }
            }
        }, this.$slots.default);
    },

    props: {
        ops: {
            default: function _default() {
                /* istanbul ignore next */
                return {
                    width: {
                        default: '5px'
                    },
                    pos: {
                        default: 'left'
                    },
                    background: {
                        default: '#a5d6a7'
                    },
                    opacity: {
                        default: '0.5'
                    }
                };
            }
        }
    }
};

// vertical scrollBar
var vScrollbar = {
    name: 'vBar',
    computed: {
        computedTop: function computedTop() {
            return this.state.top * 100;
        },
        computedHeight: function computedHeight() {
            return this.state.height * 100;
        }
    },
    render: function render(_c) {
        var vm = this;
        var style = {
            position: 'absolute',
            top: 0,
            height: vm.computedHeight + '%',
            width: vm.ops.width,
            background: vm.ops.background,
            borderRadius: '4px',
            transform: 'translateY(' + vm.computedTop + '%)',
            transition: 'opacity .5s',
            cursor: 'pointer',
            opacity: vm.state.opacity,
            userSelect: 'none'
            // determine the position
        };if (vm.ops.pos == 'right') {
            style['right'] = 0;
        } else {
            style['left'] = 0;
        }

        return _c('div', {
            style: style,
            class: "vScrollbar"
        });
    },

    props: {
        ops: {
            default: function _default() {
                /* istanbul ignore next */
                return {
                    background: 'hsla(220,4%,58%,.3)',
                    opacity: 0,
                    pos: 'left',
                    width: '5px'
                };
            }
        },
        state: {
            default: function _default() {
                /* istanbul ignore next */
                return {
                    top: {
                        default: 0
                    },
                    height: {
                        default: 0
                    },
                    opacity: {
                        default: 0
                    }
                };
            }
        }
    }
};

// horizontal rail
var hRail = {
    name: 'hRail',
    render: function render(_c) {
        var vm = this;
        var style = {
            position: 'absolute',
            left: 0,
            width: '100%',
            height: vm.ops.height,
            background: vm.ops.background,
            opacity: vm.ops.opacity,
            borderRadius: '4px'
        };
        // determine the position
        if (vm.ops.pos == 'top') {
            style['top'] = 0;
        } else {
            style['bottom'] = 0;
        }

        return _c('div', {
            style: style,
            on: {
                "click": function click(e) {
                    vm.$emit('scrollContentByBar', e, 'hScrollbar');
                }
            }
        }, this.$slots.default);
    },

    props: {
        ops: {
            default: function _default() {
                /* istanbul ignore next */
                return {};
            }
        }

    }
};

// horizontal scrollBar
var hScrollbar = {
    name: 'hBar',
    computed: {
        computedLeft: function computedLeft() {
            return this.state.left * 100;
        },
        computedWidth: function computedWidth() {
            return this.state.width * 100;
        }
    },
    render: function render(_c) {
        var vm = this;
        var style = {
            position: 'absolute',
            width: vm.computedWidth + '%',
            height: vm.ops.height,
            background: vm.ops.background,
            borderRadius: '4px',
            transform: 'translateX(' + vm.computedLeft + '%)',
            transition: 'opacity .5s',
            cursor: 'pointer',
            opacity: vm.state.opacity,
            userSelect: 'none'
            // determine the position
        };if (vm.ops.pos == 'top') {
            style['top'] = 0;
        } else {
            style['bottom'] = 0;
        }
        return _c('div', {
            style: style,
            class: "hScrollbar"
        });
    },

    props: {
        ops: {
            default: function _default() {
                /* istanbul ignore next */
                return {};
            }
        },
        state: {
            default: function _default() {
                /* istanbul ignore next */
                return {};
            }
        }
    }
};

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

/**
 * @description return the computed value of a dom
 * @author wangyi7099
 * @param {any} dom 
 * @param {any} property 
 */
function getComputed(dom, property) {
    return window.getComputedStyle(dom).getPropertyValue(property);
}

/**
 * @description deepCopy a object.
 * 
 * @param {any} source 
 * @returns 
 */
function deepCopy(source, target) {
    target = (typeof target === 'undefined' ? 'undefined' : _typeof(target)) === 'object' && target || {};
    for (var key in source) {
        target[key] = _typeof(source[key]) === 'object' ? deepCopy(source[key], target[key] = {}) : source[key];
    }
    return target;
}

/**
 * 
 * @description deepMerge a object.
 * @param {any} from 
 * @param {any} to 
 */
function deepMerge(from, to) {
    to = to || {};
    for (var key in from) {
        if (_typeof(from[key]) === 'object') {
            if (!to[key]) {
                to[key] = {};
                deepCopy(from[key], to[key]);
            } else {
                deepMerge(from[key], to[key]);
            }
        } else {
            if (!to[key]) to[key] = from[key];
        }
    }
    return to;
}
/**
 * @description define a object reactive
 * @author wangyi
 * @export
 * @param {any} target 
 * @param {any} key 
 * @param {any} source 
 */
function defineReactive(target, key, source, souceKey) {
    souceKey = souceKey || key;
    Object.defineProperty(target, key, {
        get: function get() {
            return source[souceKey];
        }
    });
}

var scrollBarWidth = void 0;

function getGutter() {
    if (Vue.prototype.$isServer) return 0;
    if (scrollBarWidth !== undefined) return scrollBarWidth;

    var outer = document.createElement('div');
    outer.className = 'el-scrollbar__wrap';
    outer.style.visibility = 'hidden';
    outer.style.width = '100px';
    outer.style.position = 'absolute';
    outer.style.top = '-9999px';
    document.body.appendChild(outer);

    var widthNoScroll = outer.offsetWidth;
    outer.style.overflow = 'scroll';

    var inner = document.createElement('div');
    inner.style.width = '100%';
    outer.appendChild(inner);

    var widthWithScroll = inner.offsetWidth;
    outer.parentNode.removeChild(outer);
    scrollBarWidth = widthNoScroll - widthWithScroll;

    getGutter.isUsed = false;

    return scrollBarWidth;
}

// scrollContent
var vueScrollContent = {
    name: 'scrollContent',
    render: function render(_c) {
        var vm = this;
        var style = deepMerge(vm.state.style, {});
        style.height = vm.ops.height;
        if (vm.ops.padding) {
            style[vm.ops.paddPos] = vm.ops.paddValue;
        }
        return _c(vm.ops.tag, {
            style: style,
            class: "scrollContent",
            props: vm.ops.props,
            attrs: vm.ops.attrs
        }, this.$slots.default);
    },

    props: {
        ops: {
            default: function _default() {
                /* istanbul ignore next */
                return {};
            }
        },
        state: {
            default: function _default() {
                /* istanbul ignore next */
                return {};
            }
        }
    }
};

// vueScrollPanel
var vueScrollPanel = {
    name: 'scrollPanel',
    render: function render(_c) {
        var vm = this;
        var getter = getGutter();
        var style = {
            overflowY: 'hidden' //'scroll'
        };
		getter = 0;//zz_xx
        if (getter) {
            style.marginRight = -getter + 'px';
            style.height = 'calc(100% + ' + getter + 'px)';
        } else {
            style.height = '100%';
            if (!getGutter.isUsed) {
                getGutter.isUsed = true;
                // add style
                var styleDom = document.createElement('style');
                styleDom.type = 'text/css';
                styleDom.innerHTML = ".vueScrollPanel::-webkit-scrollbar{width:0;height:0}";
                document.getElementsByTagName('HEAD').item(0).appendChild(styleDom);
            }
        }
        return _c('div', {
            style: style,
            class: "vueScrollPanel",
            on: {
                scroll: function scroll(e) {
                    vm.$emit('scrolling', e);
                },
                wheel: function wheel(e) {
                    vm.$emit('wheeling', e);
                }
            }
        }, this.$slots.default);
    }
};

var GCF = {
    // 
    scrollContent: {
        tag: 'div',
        padding: true,
        height: '100%',
        props: {},
        attrs: {}
    },
    // 
    vRail: {
        width: '5px',
        pos: 'left',
        background: "#a5d6a7",
        opacity: 0 //'0.5'
    },
    // 
    vBar: {
        width: '5px',
        pos: 'left',
        background: '#4caf50',
        deltaY: 100,
        keepShow: false,
        opacity: 1
    },
    // 
    hRail: {
        height: '5px',
        pos: 'bottom',
        background: "#a5d6a7",
        opacity: 0 //'0.5'
    },
    // 
    hBar: {
        height: '5px',
        pos: 'bottom',
        background: '#4caf50',
        keepShow: false,
        opacity: 1
    }
};

/**
 * hack the lifeCycle 
 * 
 * to merge the global data into user-define data
 */
function hackPropsData() {
    var vm = this;
    if (vm.$options.name === 'vueScroll') {
        var ops = deepMerge(GCF, {});
        vm.$options.propsData.ops = vm.$options.propsData.ops || {};
        Object.keys(vm.$options.propsData.ops).forEach(function (key) {
            defineReactive(vm.fOps, key, vm.$options.propsData.ops);
        });
        deepMerge(ops, vm.fOps);
        // to sync the rail and bar
        defineReactive(vm.fOps.vBar, 'pos', vm.fOps.vRail);
        defineReactive(vm.fOps.vBar, 'width', vm.fOps.vRail);
        defineReactive(vm.fOps.hBar, 'pos', vm.fOps.hRail);
        defineReactive(vm.fOps.hBar, 'height', vm.fOps.hRail);

        var prefix = "padding-";
        if (vm.fOps.scrollContent.padding) {
            Object.defineProperty(vm.fOps.scrollContent, 'paddPos', {
                get: function get() {
                    return prefix + vm.fOps.vRail.pos;
                }
            });
            Object.defineProperty(vm.fOps.scrollContent, 'paddValue', {
                get: function get() {
                    return vm.fOps.vRail.width;
                }
            });
        }
        // defineReactive(vm.scrollContent.style, )
    }
}
var LifeCycleMix = {
    created: function created() {
        hackPropsData.call(this);
    }
};

// vuescroll core module

// import config
var vueScroll = {
    name: "vueScroll",
    mixins: [LifeCycleMix],
    data: function data() {
        return {
            scrollPanel: {
                el: ""
            },
            scrollContent: {
                state: {
                    style: {
                        minHeight: '100%',
                        boxSizing: 'border-box'
                    }
                }
            },
            vRail: {
                el: ""
            },
            vScrollbar: {
                el: "",
                state: {
                    top: 0,
                    height: 0,
                    opacity: 0
                }
            },
            hRail: {
                el: ""
            },
            hScrollbar: {
                el: "",
                state: {
                    left: 0,
                    width: 0,
                    opacity: 0,
                    pos: 'bottom'
                }
            },
            listeners: [],
            mousedown: false,
            isMouseLeavePanel: true,
            isWheeling: false,
            gutter: getGutter(),
            fOps: {
                scrollContent: {},
                vRail: {},
                vBar: {},
                hRail: {},
                hBar: {}
            }
        };
    },
    render: function render(_c) {
        var vm = this;
        return _c('div', {
            class: 'vueScroll',
            style: {
                position: 'relative',
                height: '100%',
                width: '100%',
                overflow: 'hidden'
            },
            on: {
                mouseenter: function mouseenter() {
                    vm.isMouseLeavePanel = false;
                    vm.showBar();
                },
                mouseleave: function mouseleave() {
                    vm.isMouseLeavePanel = true;
                    vm.hideBar();
                },
                mousemove: function mousemove() {
                    vm.isMouseLeavePanel = false;
                    vm.showBar();
                }
            }
        }, [_c('scrollPanel', {
            ref: 'scrollPanel',
            porps: {},
            on: {
                scrolling: vm.scroll,
                wheeling: vm.wheel
            }
        }, [_c('scrollContent', {
            props: {
                ops: vm.fOps.scrollContent,
                state: vm.scrollContent.state
            }
        }, vm.$slots.default)]), _c('vRail', {
            props: {
                ops: vm.fOps.vRail
            },
            on: {
                scrollContentByBar: vm.scrollContentByBar
            },
            ref: "vRail"
        }), _c("vBar", {
            props: {
                ops: vm.fOps.vBar,
                state: vm.vScrollbar.state
            },
            ref: "vScrollbar"
        }), _c('hRail', {
            props: {
                ops: vm.fOps.hRail
            },
            on: {
                scrollContentByBar: vm.scrollContentByBar
            },
            ref: "hRail"
        }), _c('hBar', {
            props: {
                ops: vm.fOps.hBar,
                state: vm.hScrollbar.state
            },
            ref: "hScrollbar"
        })]);
    },
    mounted: function mounted() {
        this.initEl();
        this.initBarDrag();
        this.listenPanelTouch();
        // showbar at init time
        this.showBar();
    },

    methods: {
        initEl: function initEl() {
            this.scrollPanel.el = this.$refs['scrollPanel'] && this.$refs['scrollPanel'].$el;
            this.vScrollbar.el = this.$refs['vScrollbar'] && this.$refs['vScrollbar'].$el;
            this.hScrollbar.el = this.$refs['hScrollbar'] && this.$refs['hScrollbar'].$el;
            this.hRail.el = this.$refs['hRail'] && this.$refs['hRail'].$el;
            this.vRail.el = this.$refs['vRail'] && this.$refs['vRail'].$el;
        },
        initBarDrag: function initBarDrag() {
            var vScrollbar = this.listenBarDrag('vScrollbar');
            var hScrollbar = this.listenBarDrag('hScrollbar');
            vScrollbar();
            hScrollbar();
        },
        scrollTo: function scrollTo(pos) {
            var x = pos.x || this.scrollPanel.el.scrollLeft;
            var y = pos.y || this.scrollPanel.el.scrollTop;
            this.scrollPanel.el.scrollTo(x, y);
        },

        // get the bar height or width
        getBarPropertyValue: function getBarPropertyValue(type, scrollPanelPropertyValue, scrollPanelScrollPropertyValue) {
            var scrollPropertyValue = scrollPanelPropertyValue / scrollPanelScrollPropertyValue;
            if (scrollPanelScrollPropertyValue <= scrollPanelPropertyValue || Math.abs(scrollPanelPropertyValue - scrollPanelScrollPropertyValue) <= this.accuracy) {
                scrollPropertyValue = 0;
            }
            return scrollPropertyValue;
        },

        // adjust a bar's position
        adjustBarPos: function adjustBarPos(scrollPropertyValue, scrollPanelPropertyValue, scrollDirectionValue, scrollPanelScrollValue) {
            return parseFloat(scrollDirectionValue / scrollPanelPropertyValue);
        },

        // show All bar
        showBar: function showBar() {
            this.showVBar();
            this.showHBar();
        },

        // hide all bar
        hideBar: function hideBar() {
            this.hideVBar();
            this.hideHBar();
        },

        // showVbar
        showVBar: function showVBar() {
            if (!this.isMouseLeavePanel || this.fOps.vBar.keepShow || this.mousedown) {
				this.gutter = 0;//zz_xx
                var scrollPanelPropertyValue = Math.floor(getComputed(this.scrollPanel.el, 'height').replace('px', "")) - this.gutter;
                var scrollPanelScrollPropertyValue = Math.floor(this.scrollPanel.el['scrollHeight']);
                var scrollDirectionValue = Math.floor(this.scrollPanel.el['scrollTop']);
                if (this.vScrollbar.state.height = this.getBarPropertyValue('vScrollbar', scrollPanelPropertyValue, scrollPanelScrollPropertyValue)) {
                    this.vScrollbar.state.top = this.adjustBarPos(this.vScrollbar.state.height, scrollPanelPropertyValue - 0, scrollDirectionValue, scrollPanelScrollPropertyValue);
                    this.vScrollbar.state.opacity = this.fOps.vBar.opacity;
                }
            }
        },

        // showHbar
        showHBar: function showHBar() {
            if (!this.isMouseLeavePanel || this.fOps.hBar.keepShow || this.mousedown) {
                var scrollPanelPropertyValue = Math.floor(getComputed(this.scrollPanel.el, 'width').replace('px', "")) - this.gutter;
                var scrollPanelScrollPropertyValue = Math.floor(this.scrollPanel.el['scrollWidth']);
                var scrollDirectionValue = Math.floor(this.scrollPanel.el['scrollLeft']);
                if (this.hScrollbar.state.width = this.getBarPropertyValue('hScrollbar', scrollPanelPropertyValue, scrollPanelScrollPropertyValue)) {
                    this.hScrollbar.state.left = this.adjustBarPos(this.hScrollbar.state.width, scrollPanelPropertyValue - 0, scrollDirectionValue, scrollPanelScrollPropertyValue);
                    this.hScrollbar.state.opacity = this.fOps.hBar.opacity;
                }
            }
        },

        // hideVbar
        hideVBar: function hideVBar() {
            if (!this.fOps.vBar.keepShow) {
                if (!this.mousedown && this.isMouseLeavePanel) {
                    this.vScrollbar.state.opacity = 0;
                }
            }
        },

        // hideHbar
        hideHBar: function hideHBar() {
            if (!this.fOps.hBar.keepShow) {
                if (!this.mousedown && this.isMouseLeavePanel) {
                    this.hScrollbar.state.opacity = 0;
                }
            }
        },
        wheel: function wheel(e) {
            var vm = this;
            var delta = vm.fOps.vBar.deltaY;
            vm.isWheeling = true;
            vm.showVBar();
            vm.scrollBar(e.deltaY > 0 ? delta : -delta, 'vScrollbar');
            e.preventDefault();
            e.stopPropagation();
        },

        // listen wheel scrolling
        scroll: function scroll(e) {
            // console.log(e);
            if (this.isWheeling) {
                e.preventDefault();
                this.isWheeling = false;
                return;
            }
            this.showBar();
        },

        // scroll content and resize bar.
        scrollBar: function scrollBar(distance, type) {
            // >0 scroll to down or right  <0 scroll to up or left
            var direction = type == 'vScrollbar' ? 'top' : 'left';
            var upperCaseDirection = type == 'vScrollbar' ? 'Top' : 'Left';
            var property = type == 'vScrollbar' ? 'height' : 'width';
            var upperCaseProperty = type == 'vScrollbar' ? 'Height' : 'Width';
            var event = type == 'vScrollbar' ? 'vscroll' : 'hscroll';
            var showEvent = type == 'vScrollbar' ? 'showVBar' : 'showHBar';
            var directionValue = this[type].state[direction];
            var scrollPanelPropertyValue = getComputed(this.scrollPanel.el, property).replace('px', "") - this.gutter;
            if (type == 'vScrollbar') {
                scrollPanelPropertyValue = scrollPanelPropertyValue;
            }
            var scrollPanelScrollValue = this.scrollPanel.el['scroll' + upperCaseProperty];
            var scrollDirectionValue = this.scrollPanel.el['scroll' + upperCaseDirection];
            var scrollPropertyValue = this[type].state[property];
            var ScrollDirectionValue = Math.round(scrollDirectionValue + distance);
            if (distance < 0) {
                // scroll up or left
                this.scrollPanel.el['scroll' + upperCaseDirection] = Math.max(0, ScrollDirectionValue);
            } /* istanbul ignore next */else if (distance > 0) {
                    // scroll down or right
                    this.scrollPanel.el['scroll' + upperCaseDirection] = Math.min(scrollPanelScrollValue - scrollPanelPropertyValue, ScrollDirectionValue);
                }
            this[showEvent]();
            var content = {};
            var bar = {};
            var process = "";

            ScrollDirectionValue = this.scrollPanel.el['scroll' + upperCaseDirection];
            content.residual = scrollPanelScrollValue - ScrollDirectionValue - scrollPanelPropertyValue;
            content.scrolled = ScrollDirectionValue;
            bar.scrolled = this[type].state[direction];
            bar.residual = content.residual / scrollPanelScrollValue * scrollPanelPropertyValue;
            bar[property] = this[type].state[property] * scrollPanelPropertyValue;
            process = ScrollDirectionValue / (scrollPanelScrollValue - scrollPanelPropertyValue);
            bar.name = type;
            content.name = "content";
            this.$emit(event, bar, content, process);
        },

        // convert scrollbar's distance to content distance.
        _scrollContent: function _scrollContent(distance, type) {
            var property = type == 'vScrollbar' ? 'height' : 'width';
            var upperCaseProperty = type == 'vScrollbar' ? 'Height' : 'Width';
            var scrollPanelPropertyValue = getComputed(this.scrollPanel.el, property).replace('px', "") - this.gutter;
            var scrollPanelScrollValue = this.scrollPanel.el['scroll' + upperCaseProperty];
            var scrollContentDistance = scrollPanelScrollValue * (distance / scrollPanelPropertyValue);
            this.scrollBar(scrollContentDistance, type);
        },

        // click the rail and trigger the scrollbar moving
        scrollContentByBar: function scrollContentByBar(e, type) {
            var coco = type === 'vScrollbar' ? 'y' : 'x';
            var elementInfo = this[type].el.getBoundingClientRect();
            var delta = e[coco] - elementInfo[coco] - elementInfo.height / 2;
            this._scrollContent(delta, type);
        },
        listenBarDrag: function listenBarDrag(type) {
            var vm = this;
            var coordinate = type === 'vScrollbar' ? 'pageY' : 'pageX';
            var bar = type === 'vScrollbar' ? 'VBar' : 'HBar';
            return function () {
                var pre = void 0;
                var now = void 0;

                function move(e) /* istanbul ignore next */{
                    now = e[coordinate];
                    var delta = now - pre;
                    vm['show' + bar]();
                    vm._scrollContent(delta, type);
                    pre = now;
                }

                function t(e) /* istanbul ignore next */{
                    e.stopPropagation();
                    vm.mousedown = true;
                    pre = e[coordinate];
                    vm['show' + bar]();
                    document.onselectstart = function () {
                        return false;
                    };
                    document.addEventListener('mousemove', move);
                    document.addEventListener('mouseup', function (e) {
                        vm.mousedown = false;
                        document.onselectstart = null;
                        vm['hide' + bar]();
                        document.removeEventListener('mousemove', move);
                    });
                }
                vm.listeners.push({
                    dom: vm[type].el,
                    event: t,
                    type: "mousedown"
                });
                vm[type].el.addEventListener('mousedown', t);
            };
        },
        listenPanelTouch: function listenPanelTouch() {
            var vm = this;
            var pannel = this.scrollPanel.el;
            function t(e) /* istanbul ignore next */{
                if (e.touches.length) {
                    e.stopPropagation();
                    vm.mousedown = true;
                    vm.showBar();
                    pannel.addEventListener('touchend', function (e) {
                        vm.mousedown = false;
                        vm.hideBar();
                    });
                }
            }
            pannel.addEventListener('touchstart', t);
            vm.listeners.push({
                dom: pannel,
                event: t,
                type: "touchstart"
            });
        }
    },
    beforeDestroy: function beforeDestroy() {
        // remove the registryed event.
        this.listeners.forEach(function (item) {
            item.dom.removeEventListener(item.type, item.event);
        });
    },
    updated: function updated() {
        this.showBar();
        this.hideBar();
    },

    props: {
        ops: {
            default: function _default() {
                return {
                    scrollContent: {},
                    vRail: {},
                    vBar: {},
                    hRail: {},
                    hBar: {}
                };
            }
        },
        accuracy: {
            default: 5
        }
    }
};

// import component
// import config
var scroll = {
    install: function install(Vue$$1) {
        if (scroll.isInstalled) {
            console.warn("You should not install the vuescroll again!");
            return;
        }
        Vue$$1.component(vRail.name, vRail);
        Vue$$1.component(vScrollbar.name, vScrollbar);
        Vue$$1.component(hRail.name, hRail);
        Vue$$1.component(hScrollbar.name, hScrollbar);
        Vue$$1.component(vueScrollContent.name, vueScrollContent);
        Vue$$1.component(vueScrollPanel.name, vueScrollPanel);
        //vueScroll
        Vue$$1.component(vueScroll.name, vueScroll);

        // registry the globe setting
        Vue$$1.prototype.$vuescrollConfig = GCF;

        scroll.isInstalled = true;
    }
};

if (typeof Vue !== 'undefined') {
    Vue.use(scroll);
}

return scroll;

})));
